bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDMoments.compute_dims_from_values
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDMoments.compute_dims_from_values